## This file contains some of the options that can be changed to customize
## your Ren'Py game. It only contains the most common options... there
## is quite a bit more customization you can do.
##
## Lines beginning with two '#' marks are comments, and you shouldn't
## uncomment them. Lines beginning with a single '#' mark are
## commented-out code, and you may want to uncomment them when
## appropriate.
init:
    python:

        # A window placed behind the day planner (empty).
        style.create('dp_window', 'window')
        style.dp_window.ypos = 160
        style.dp_window.yanchor = 'top'

        # The grid containing the three choices in the day planner.
        style.create('dp_grid', 'default')
        style.dp_grid.xfill = True
        
        # Windows containing the groups of choices in the day planner.
        style.create('dp_choice', 'default')
        style.dp_choice.xpos = 0.4
        style.dp_choice.xanchor = 'center'

        # Action buttons.
        style.create('dp_button', 'button')
        style.create('dp_button_text', 'button_text')

        style.create('dp_done_button', 'button')
        style.create('dp_done_button_text', 'button_text')

        style.dp_done_button.ypos = 0.95
        style.dp_done_button.yanchor = 'bottom'
        
        # Labels.
        style.create('dp_label', 'default')
        style.dp_label.xpos = 0.5
        style.dp_label.xanchor = 'center'

        # The amount of padding between the label and the action
        # in a choice.
        dp_padding = 12 

        # The amount of padding between the choices and done.
        dp_done_padding = 32

        # The title of the done button.
        dp_done_title = "Finished"

    python:

        # A list of the periods of the day that are present in the
        # day planner. This can be changed at runtime.
        dp_period_names = [ "Morning", "Afternoon", "Evening", "Night" ]

        # A list of variables that will take the selected choices
        # for each of the periods named above.
        dp_period_vars = [ "morning_act",
                           "afternoon_act",
                           "evening_act",
                           "night_act", ]

        # A map from the period names to a list of the activities
        # available for that period. This may be conputed before
        # each call to day_planner. Each entry is a tuple, where
        # the first element is the name shown to the user, and the
        # second is the name assigned to the variable for that
        # period.
        dp_period_acts = {        
            'Morning': [
            ( 'Music Class', "class" ),
            ( 'Cut Class', "cut"),
            ],
            
            'Afternoon': [
            ( 'Practice Songs', "practice" ),
            ( 'Take a Nap', "nap" ),
            ( 'Study', "study1" ),
            ],
            
            'Evening' : [
            ( 'Listen to Music', "listen" ),
            ( 'Study', "study2" ),
            ],
            
            'Night' : [
            ( 'Watch TV', "tv" ),
            ( 'Study', "study3" ),
            ( 'Sleep', "sleep" ),
            ],
            }

        

# We assume that the various period variables have been assigned
# default values by this point.
label day_planner:

    call dp_callback from _call_dp_callback_1

    python hide:

        renpy.choice_for_skipping()

        ui.window(style='dp_window')
        ui.vbox(dp_done_padding)

        ui.grid(len(dp_period_names), 1, xfill=True, style='dp_grid')

        # True iff every period has a valid value.
        can_continue = True

        for period, var in zip(dp_period_names, dp_period_vars):

            ui.window(style='dp_choice')
            ui.vbox()

            _label_factory(period, "dp")
            ui.null(height=dp_padding)

            valid_value = False

            for label, value in dp_period_acts[period]:

                def clicked(var=var, value=value):
                    setattr(store, var, value)
                    return True

                valid_value |= getattr(store, var) == value

                _button_factory(label, "dp",
                                selected = getattr(store, var) == value,
                                clicked=clicked)

            can_continue &= valid_value

            ui.close()

        ui.close()

        if can_continue:
            clicked = lambda : False
        else:
            clicked = None
            
        _button_factory(dp_done_title, "dp_done",
                        clicked = clicked )

        ui.close()

        
    if ui.interact():
        jump day_planner

    return 

init:
    $ config.main_menu.insert(2, ('Extra Stories', "extra", "True"))

    python:
        def story(filename_hover, filename, target, condition):
            if eval (condition):
                clicked = ui.jumps(target)

            else:
                clicked = None

                
            ui.imagebutton(filename_hover, filename, clicked=clicked, hovered=None, image_style='image_button_image')

    python hide:

        ## Should we enable the use of developer tools? This should be
        ## set to False before the game is released, so the user can't
        ## cheat using developer tools.

        config.developer = False

        ## These control the width and height of the screen.

        config.screen_width = 800
        config.screen_height = 600

        ## This controls the title of the window, when Ren'Py is
        ## running in a window.

        config.window_title = u"Jasper & Augustus in: THE MISSING TICKETS"

        ## We then want to call a theme function. themes.roundrect is
        ## a theme that features the use of rounded rectangles. It's
        ## the only theme we currently support.
        ##
        ## The theme function takes a number of parameters that can
        ## customize the color scheme.
        theme.roundrect(

            ## The color of an idle widget face.
            widget = "#D96B00",

            ## The color of a focused widget face.
            widget_hover = "#FD9B1C",

            ## The color of the text in a widget.
            widget_text = "#FCE6B1",

            ## The color of the text in a selected widget. (For
            ## example, the current value of a preference.)
            widget_selected = "#ffffff",

            ## The color of a disabled widget face. 
            disabled = "#FFECBF",

            ## The color of disabled widget text.
            disabled_text = "#ffffff",

            ## The color of informational labels.
            label = "#502F13",

            ## The color of a frame containing widgets.
            frame = "#FFECBF",

            ## If this is True, in-game menus are placed in the center
            ## the screen. If False, they are placed inside a window
            ## at the bottom of the screen.
            button_menu = True,

            ## If this is True, the in-game window is rounded. If False,
            ## the in-game window is square.
            rounded_window = False,

            ## The background of the main menu. This can be a color
            ## beginning with '#', or an image filename. The latter
            ## should take up the full height and width of the screen.
            mm_root = "#FDF5E3",

            ## The background of the game menu. This can be a color
            ## beginning with '#', or an image filename. The latter
            ## should take up the full height and width of the screen.
            gm_root = Image('main4.png'),

            ## And we're done with the theme. The theme will customize
            ## various styles, so if we want to change them, we should
            ## do so below.            
            )


        #########################################
        ## These settings let you customize the window containing the
        ## dialogue and narration, by replacing it with an image.

        ## The background of the window. In a Frame, the two numbers
        ## are the size of the left/right and top/bottom borders,
        ## respectively.

        style.window.background = Frame("AJframe.png", 12, 12)
        
        ## Margin is space surrounding the window, where the background
        ## is not drawn.

        # style.window.left_margin = 6
        # style.window.right_margin = 6
        # style.window.top_margin = 6
        # style.window.bottom_margin = 6
        
        ## Padding is space inside the window, where the background is
        ## drawn.

        # style.window.left_padding = 6
        # style.window.right_padding = 6
        # style.window.top_padding = 6
        # style.window.bottom_padding = 6

        ## This is the minimum height of the window, including the margins
        ## and padding.

        style.window.yminimum = 130


        #########################################
        ## This lets you change the placement of the main menu.
        
        ## The way placement works is that we find an anchor point
        ## inside a displayable, and a position (pos) point on the
        ## screen. We then place the displayable so the two points are
        ## at the same place.

        ## An anchor/pos can be given as an integer or a floating point
        ## number. If an integer, the number is interpreted as a number
        ## of pixels from the upper-left corner. If a floating point,
        ## the number is interpreted as a fraction of the size of the
        ## displayable or screen.

        style.mm_menu_frame.xpos = 0
        style.mm_menu_frame.xanchor = 0
        style.mm_menu_frame.ypos = 0.98
        style.mm_menu_frame.yanchor = .98


        #########################################
        ## These let you customize the default font used for text in Ren'Py.

        ## The file containing the default font.

        style.default.font = "Soft Compound.ttf"

        ## The default size of text.

        style.default.size = 30

        ## Note that these only change the size of some of the text. Other
        ## buttons have their own styles.


        #########################################
        ## These settings let you change some of the sounds that are used by
        ## Ren'Py.

        ## Set this to False if the game does not have any sound effects.

        config.has_sound = True

        ## Set this to False if the game does not have any music.

        config.has_music = True

        ## Set this to False if the game does not have voicing.

        config.has_voice = False

        ## Sounds that are used when button and imagemaps are clicked.

        style.button.activate_sound = "pop.mp3"
        style.imagemap.activate_sound = "pop.mp3"

        ## Sounds that are used when entering and exiting the game menu.

        config.enter_sound = "accent.ogg"
        config.exit_sound = "accent.ogg"

        ## A sample sound that can be played to check the sound volume.

        config.sample_sound = "accent.ogg"

        ## Music that is played while the user is at the main menu.

        config.main_menu_music = "Oregon_Surf.mp3"

        
        #########################################
        ## Miscellaneous customizations

        ## These let you change the transitions that are used when entering
        ## and exiting the game menu.

        config.enter_transition = wiperight
        config.exit_transition = wipeleft

        ## Note: The following two options are only evaluated the first time
        ## a game is run. To have them run a second time, delete
        ## game/saves/persistent
        
        ## Should we start in fullscreen mode?
        config.default_fullscreen = False

        ## The default text speed in characters per second. 0 is infinite.
        config.default_text_cps = 140

